Conference event package performance improvement.

- Instead of sending each participant to the telephony conference
controller, all participants are sent at once.  This way the conference
only needs to be recalculated once.

Bug: 18057361
Change-Id: I86205fc7f1d2648bb180fc7eaf3ad611955952f9
diff --git a/telecomm/java/android/telecom/Connection.java b/telecomm/java/android/telecom/Connection.java
index 4135ec3..61b471c 100644
--- a/telecomm/java/android/telecom/Connection.java
+++ b/telecomm/java/android/telecom/Connection.java
@@ -83,8 +83,8 @@
                 Connection c, List<Connection> conferenceableConnections) {}
         public void onConferenceChanged(Connection c, Conference conference) {}
         /** @hide */
-        public void onConferenceParticipantChanged(Connection c, ConferenceParticipant participant)
-        {}
+        public void onConferenceParticipantsChanged(Connection c,
+                List<ConferenceParticipant> participants) {}
     }
 
     /** @hide */
@@ -1124,14 +1124,15 @@
     }
 
     /**
-     * Notifies listeners of a change to a conference participant.
+     * Notifies listeners of a change to conference participant(s).
      *
      * @param conferenceParticipant The participant.
      * @hide
      */
-    protected final void updateConferenceParticipant(ConferenceParticipant conferenceParticipant) {
+    protected final void updateConferenceParticipants(
+            List<ConferenceParticipant> conferenceParticipants) {
         for (Listener l : mListeners) {
-            l.onConferenceParticipantChanged(this, conferenceParticipant);
+            l.onConferenceParticipantsChanged(this, conferenceParticipants);
         }
     }
 }
@@ -1124,14 +1124,15 @@
      *
-     * @param conferenceParticipant The participant.
+     * @param conferenceParticipants The participants.
      * @hide
      */